pyhsm.validate_cmd.YHSM_Cmd_AEAD_Validate_OTP

Package pyhsm :: Module validate_cmd :: Class YHSM_Cmd_AEAD_Validate_OTP |
[frames] | no frames]

# Class YHSM_Cmd_AEAD_Validate_OTP

          cmd.YHSM_Cmd --+
                         |
    aead_cmd.YHSM_AEAD_Cmd --+
                             |
                            YHSM_Cmd_AEAD_Validate_OTP

Request the YubiHSM to validate an OTP using an externally stored AEAD.

Instance Methods
__init__(self, stick, public_id, otp, key_handle, aead) The base class for all YSM_ commands. |
parse_result(self, data) Returns a YHSM_GeneratedAEAD instance, or throws pyhsm.exception.YHSM_CommandFailed. |
Inherited from `aead_cmd.YHSM_AEAD_Cmd`: `__repr__` Inherited from `cmd.YHSM_Cmd`: `execute`

Class Variables
| response = `None`
| status = `None`
Inherited from `aead_cmd.YHSM_AEAD_Cmd`: `key_handle`, `nonce` Inherited from `cmd.YHSM_Cmd`: `executed`, `response_status`

Method Details

### __init__(self, stick, public_id, otp, key_handle, aead) (Constructor) |
The base class for all YSM_ commands. Parameters: `stick` - Reference to a YubiHSM `command` - The YSM_xxx command defined in pyhsm.defines. `payload` - a packed C struct, represented as a Python string Overrides: cmd.YHSM_Cmd.__init__ (inherited documentation)

### parse_result(self, data) |
Returns a YHSM_GeneratedAEAD instance, or throws pyhsm.exception.YHSM_CommandFailed. Overrides: cmd.YHSM_Cmd.parse_result (inherited documentation)